pub async fn migrate(pool: &DbPool) -> Result<(), MigrateError>Expand description
Apply the bundled Runledger schema migrations to a PostgreSQL pool.
pub async fn migrate(pool: &DbPool) -> Result<(), MigrateError>Apply the bundled Runledger schema migrations to a PostgreSQL pool.