#[non_exhaustive]pub enum CompareAndReplaySucceededJobOutcome {
Replayed {
source_job_id: Uuid,
source_run_number: i32,
replay: JobEnqueueOutcome,
},
ExpectationMismatch {
actual: Box<JobQueueRecord>,
},
NotFound,
}Expand description
Result of compare-and-replay.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Replayed
The replay exists. replay.disposition distinguishes a newly inserted
replay from an idempotent retry that resolved to the existing replay.
ExpectationMismatch
The exactly scoped source exists but no longer matches the successful run observed by the caller.
Fields

actual: Box<JobQueueRecord>NotFound
No source job exists in the exact requested scope.