#[non_exhaustive]pub enum EnqueueActiveWorkflowOutcome {
Inserted(WorkflowRunDbRecord),
ExistingActive(WorkflowRunDbRecord),
ExistingIdempotent(WorkflowRunDbRecord),
}Expand description
Classified result of enqueueing with a reusable workflow active key.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Inserted(WorkflowRunDbRecord)
A new workflow run and active claim were inserted.
ExistingActive(WorkflowRunDbRecord)
The active key is still owned by a prior non-quiesced workflow run.
This can be a terminal canceled run whose live handler lease has not quiesced yet.
ExistingIdempotent(WorkflowRunDbRecord)
The permanent idempotency key matched an identical prior request.
Implementations
Sourceimpl EnqueueActiveWorkflowOutcome
impl EnqueueActiveWorkflowOutcome
pub const fn workflow_run(&self) -> &WorkflowRunDbRecord