#[non_exhaustive]pub enum JobDefinitionCatalogSyncError {
ActiveScheduleForAbsentJobType(JobScheduleJobTypeReference),
ActiveScheduleForDisabledJobType(JobScheduleJobTypeReference),
CriticalSectionTimeoutFailure(Error),
ScheduleLockFailure(Error),
DefinitionLockFailure(Error),
ScheduleCheckFailure(Error),
ValidationFailure(Error),
DefinitionInspectFailure(Error),
DefinitionSyncFailure {
job_type: String,
source: Error,
},
DisableAbsentFailure(Error),
}Expand description
Error returned while applying a catalog-owned job-definition sync.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ActiveScheduleForAbsentJobType(JobScheduleJobTypeReference)
An active schedule references an enabled scoped definition absent from the catalog.
ActiveScheduleForDisabledJobType(JobScheduleJobTypeReference)
An active schedule references a catalog definition that would be disabled.
CriticalSectionTimeoutFailure(Error)
Applying transaction-local statement timeout bounds failed.
ScheduleLockFailure(Error)
Locking job_schedules before disabling definitions failed.
DefinitionLockFailure(Error)
Locking job_definitions before disabling definitions failed.
ScheduleCheckFailure(Error)
Checking active schedules before disabling definitions failed.
ValidationFailure(Error)
Sync input failed validation before any catalog writes.
DefinitionInspectFailure(Error)
Inspecting existing definitions before sync failed.
DefinitionSyncFailure
Syncing one catalog definition failed.
Fields
DisableAbsentFailure(Error)
Disabling absent scoped definitions failed.