pub struct JobContinuationUpdate<'a> {
pub delay: Duration,
pub progress_done: Option<i64>,
pub progress_total: Option<i64>,
pub checkpoint: Option<&'a Value>,
}Expand description
Progress and scheduling data for a successful handler continuation.
Fields
delay: DurationHow long to wait before the next run becomes claimable. Zero means the
next run is immediately eligible. Delays whose resulting timestamp is
outside the persistence driver’s representable range are rejected with
job.invalid_continuation_delay.
progress_done: Option<i64>progress_total: Option<i64>checkpoint: Option<&'a Value>Trait Implementations
Sourceimpl<'a> Clone for JobContinuationUpdate<'a>
impl<'a> Clone for JobContinuationUpdate<'a>
Sourcefn clone(&self) -> JobContinuationUpdate<'a>
fn clone(&self) -> JobContinuationUpdate<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<'a> Freeze for JobContinuationUpdate<'a>
impl<'a> RefUnwindSafe for JobContinuationUpdate<'a>
impl<'a> Send for JobContinuationUpdate<'a>
impl<'a> Sync for JobContinuationUpdate<'a>
impl<'a> Unpin for JobContinuationUpdate<'a>
impl<'a> UnsafeUnpin for JobContinuationUpdate<'a>
impl<'a> UnwindSafe for JobContinuationUpdate<'a>