pub struct JobDefinitionCatalogSyncReport {
pub disabled_absent_job_types: Vec<JobTypeName>,
pub disabled_catalog_job_types: Vec<JobTypeName>,
}Expand description
Summary of definition rows changed by a catalog sync.
Fields
disabled_absent_job_types: Vec<JobTypeName>Enabled definitions in the exact-sync scope that were absent from the catalog and changed to disabled.
disabled_catalog_job_types: Vec<JobTypeName>Catalog definitions changed to disabled because the catalog synced them
with is_enabled = false.