#[non_exhaustive]pub struct JobEnqueueIntentMetricsRecord {
pub job_type: JobTypeName,
pub pending_count: i64,
pub retrying_count: i64,
pub max_promotion_attempts: i32,
pub conflicted_24h: i64,
pub promoted_24h: i64,
pub oldest_pending_at: Option<DateTime<Utc>>,
}Expand description
Operational backlog signals for one intent job type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_type: JobTypeNameCanonical job type shared by every population in this record.
pending_count: i64Number of intents currently awaiting promotion.
retrying_count: i64Number of pending intents whose promotion has already been attempted.
max_promotion_attempts: i32Highest promotion-attempt count among pending intents.
This is zero when the returned job type has no pending intents.
conflicted_24h: i64Number of intents that entered the terminal conflicted state during the preceding 24 hours.
promoted_24h: i64Number of retained intents promoted during the preceding 24 hours.
oldest_pending_at: Option<DateTime<Utc>>Creation time of the oldest pending intent, if one exists.